@@ -802,7 +802,6 @@ namespace Breeze
         {
 
             frameRect.translate(1, 1);
-            // painter->translate( 1, 1 );
 
         } else {
 
@@ -1239,7 +1238,7 @@ namespace Breeze
         painter->setRenderHints( QPainter::Antialiasing );
         painter->translate( QRectF( rect ).center() );
         painter->setBrush( Qt::NoBrush );
-        painter->setPen( QPen( color, 1.5 ) );
+        painter->setPen( QPen( color, 1.1 ) );
         painter->drawPolyline( arrow );
         painter->restore();
 
@@ -1279,65 +1278,48 @@ namespace Breeze
 
         }
 
+        pen.setCapStyle( Qt::RoundCap );
+        pen.setJoinStyle( Qt::MiterJoin );
+        pen.setWidthF( 1.1*qMax(1.0, 18.0/rect.width() ) );
+        painter->setPen( pen );
+
         switch( buttonType )
         {
             case ButtonClose:
             {
-
-                // adjust pen and assign
-                const qreal penWidth( 1 );
-                pen.setWidth( 2*penWidth );
-                painter->setPen( pen );
-
-                // render
-                painter->drawLine( QPointF( 5 + penWidth, 5 + penWidth ), QPointF( 13 - penWidth, 13 - penWidth ) );
-                painter->drawLine( 13 - penWidth, 5 + penWidth, 5 + penWidth, 13 - penWidth );
+                painter->drawLine( QPointF( 5, 5 ), QPointF( 13, 13 ) );
+                painter->drawLine( 13, 5, 5, 13 );
                 break;
-
             }
 
             case ButtonMaximize:
             {
-                const qreal penWidth( 1 );
-                pen.setWidth( 2*penWidth );
-                painter->setPen( pen );
-
                 painter->drawPolyline( QPolygonF()
-                    << QPointF( 3.5 + penWidth, 11.5 - penWidth )
-                    << QPointF( 9, 5.5 + penWidth )
-                    << QPointF( 14.5 - penWidth, 11.5 - penWidth ) );
-
+                    << QPointF( 4, 11 )
+                    << QPointF( 9, 6 )
+                    << QPointF( 14, 11 ) );
                 break;
             }
 
             case ButtonMinimize:
             {
-                const qreal penWidth( 1 );
-                pen.setWidth( 2*penWidth );
-                painter->setPen( pen );
 
                 painter->drawPolyline( QPolygonF()
-                    << QPointF( 3.5 + penWidth, 6.5 + penWidth )
-                    << QPointF( 9, 12.5 - penWidth )
-                    << QPointF( 14.5 - penWidth, 6.5 + penWidth ) );
-
+                    << QPointF( 4, 7 )
+                    << QPointF( 9, 12 )
+                    << QPointF( 14, 7 ) );
                 break;
             }
 
             case ButtonRestore:
             {
-
-                const qreal penWidth( 1 );
-                pen.setWidth( 2*penWidth );
                 pen.setJoinStyle( Qt::RoundJoin );
                 painter->setPen( pen );
-
                 painter->drawPolygon( QPolygonF()
-                    << QPointF( 3.5 + penWidth, 9 )
-                    << QPointF( 9, 3.5 + penWidth )
-                    << QPointF( 14.5 - penWidth, 9 )
-                    << QPointF( 9, 14.5 - penWidth ) );
-
+                    << QPointF( 4.5, 9 )
+                    << QPointF( 9, 4.5 )
+                    << QPointF( 13.5, 9 )
+                    << QPointF( 9, 13.5 ) );
                 break;
             }
 
@@ -1366,15 +1348,7 @@ namespace Breeze
 
     //______________________________________________________________________________
     QRectF Helper::shadowRect( const QRectF& rect ) const
-    {
-        switch( StyleConfigData::lightSource() )
-        {
-            case StyleConfigData::LS_TOP: return rect.adjusted( 0.5, 0.5, -0.5, -0.5 ).translated( 0, 0.5 );
-            case StyleConfigData::LS_TOPLEFT: return rect.adjusted( 0.5, 0.5, -0.5, -0.5 ).translated( 0.5, 0.5 );
-            case StyleConfigData::LS_TOPRIGHT: return rect.adjusted( 0.5, 0.5, -0.5, -0.5 ).translated( -0.5, 0.5 );
-            default: return rect;
-        }
-    }
+    { return rect.adjusted( 0.5, 0.5, -0.5, -0.5 ).translated( 0.5, 0.5 ); }
 
     //______________________________________________________________________________
     QPainterPath Helper::roundedPath( const QRectF& rect, Corners corners, qreal radius ) const
